package czerwony.kapturek.jbspell.ispell;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import com.borland.jbcl.layout.*;
import com.borland.primetime.ide.*;
import com.borland.primetime.properties.*;
import com.borland.primetime.help.HelpTopic;


class ConfigPanel extends PropertyPage
{
    private JLabel      labelExecutable = new JLabel("Path to ispell executable:");
    private JTextField  textExecutable = new JTextField();
    private JButton     buttonExecutable = new JButton("...");

    private JCheckBox   checkAltDict = new JCheckBox("Use alternate dictionary:");
    private JTextField  textAltDict = new JTextField();
    private JButton     buttonAltDict = new JButton("...");

    private JCheckBox   checkAltPersonalDict = new JCheckBox("Use alternate personal dictionary:");
    private JTextField  textAltPersonalDict = new JTextField();
    private JButton     buttonAltPersonalDict = new JButton("...");

    private JCheckBox checkOption_P = new JCheckBox("Don\'t generate extra root/affix combinations");
    private JCheckBox checkOption_B = new JCheckBox("Report run-together words with missing blanks as spelling errors");
    private JCheckBox checkOption_m = new JCheckBox("Make possible root/affix combinations that aren\'t in the dictionary");
    private JCheckBox checkOption_C = new JCheckBox("Consider run-together words as legal compounds");
    private JCheckBox checkOption_S = new JCheckBox("Sort the list of guesses by probable correctness");

    private GridBagLayout gridBagLayout = new GridBagLayout();

    public ConfigPanel()
    {
        jbInit();
        buttonAltDict.addActionListener(new BrowseListener(textAltDict));
        buttonAltPersonalDict.addActionListener(new BrowseListener(textAltPersonalDict));
        buttonExecutable.addActionListener(new BrowseListener(textExecutable));
    }


    private void jbInit()
    {
        this.setLayout(new VerticalFlowLayout(VerticalFlowLayout.TOP, true, false));

        JPanel  panel = new JPanel(new GridBagLayout());
        panel.add(labelExecutable, new GridBagConstraints(0,0,1,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(textExecutable, new GridBagConstraints(1,0,2,1,1,0,GridBagConstraints.WEST,GridBagConstraints.HORIZONTAL, new Insets(0,0,0,0),0,0));
        panel.add(buttonExecutable, new GridBagConstraints(3,0,1,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(new JLabel(" "),  new GridBagConstraints(0,1,1,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(checkAltDict, new GridBagConstraints(0,2,2,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(textAltDict, new GridBagConstraints(2,2,1,1,1,0,GridBagConstraints.WEST,GridBagConstraints.HORIZONTAL, new Insets(0,0,0,0),0,0));
        panel.add(buttonAltDict, new GridBagConstraints(3,2,1,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(checkAltPersonalDict, new GridBagConstraints(0,3,2,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        panel.add(textAltPersonalDict, new GridBagConstraints(2,3,1,1,1,0,GridBagConstraints.WEST,GridBagConstraints.HORIZONTAL, new Insets(0,0,0,0),0,0));
        panel.add(buttonAltPersonalDict, new GridBagConstraints(3,3,1,1,0,0,GridBagConstraints.WEST,GridBagConstraints.NONE, new Insets(0,0,0,0),0,0));
        add(panel);
        add(new JLabel(" "));
        //add(checkOption_B);
        add(checkOption_C);
        //add(checkOption_P);
        //add(checkOption_m);
        add(checkOption_S);
    }


    public void readProperties()
    {
        checkOption_P.setSelected(Settings.option_P.getBoolean());
        checkOption_B.setSelected(Settings.option_B.getBoolean());
        checkOption_m.setSelected(Settings.option_m.getBoolean());
        checkOption_C.setSelected(Settings.option_C.getBoolean());
        checkOption_S.setSelected(Settings.option_S.getBoolean());

        textExecutable.setText(Settings.executablePath.getValue());
        textAltDict.setText(Settings.altDict.getValue());
        textAltPersonalDict.setText(Settings.altPersonalDict.getValue());
        checkAltDict.setSelected(Settings.useAltDict.getBoolean());
        checkAltPersonalDict.setSelected(Settings.useAltPersonalDict.getBoolean());
    }


    public void writeProperties()
    {
        Settings.restartISpell =
                Settings.option_P.getBoolean() != checkOption_P.isSelected()
            ||  Settings.option_B.getBoolean() != checkOption_B.isSelected()
            ||  Settings.option_m.getBoolean() != checkOption_m.isSelected()
            ||  Settings.option_C.getBoolean() != checkOption_C.isSelected()
            ||  Settings.option_S.getBoolean() != checkOption_S.isSelected()
            ||  Settings.useAltDict.getBoolean() != checkAltDict.isSelected()
            ||  Settings.useAltPersonalDict.getBoolean() != checkAltPersonalDict.isSelected()
            ||  !Settings.executablePath.getValue().equals(textExecutable.getText())
            ||  !Settings.altDict.getValue().equals(textAltDict.getText())
            ||  !Settings.altPersonalDict.getValue().equals(textAltPersonalDict.getText());

        Settings.option_P.setBoolean(checkOption_P.isSelected());
        Settings.option_B.setBoolean(checkOption_B.isSelected());
        Settings.option_m.setBoolean(checkOption_m.isSelected());
        Settings.option_C.setBoolean(checkOption_C.isSelected());
        Settings.option_S.setBoolean(checkOption_S.isSelected());

        Settings.executablePath.setValue(textExecutable.getText());
        Settings.altDict.setValue(textAltDict.getText());
        Settings.altPersonalDict.setValue(textAltPersonalDict.getText());
        Settings.useAltDict.setBoolean(checkAltDict.isSelected());
        Settings.useAltPersonalDict.setBoolean(checkAltPersonalDict.isSelected());
    }


    public HelpTopic getHelpTopic()
    {
        return null;
    }

    class BrowseListener implements ActionListener
    {
        JTextField  txt;

        BrowseListener(JTextField txt)
        {
            this.txt = txt;
        }

        public void actionPerformed(ActionEvent ev)
        {
            JFileChooser jfc = new JFileChooser();
            jfc.setAcceptAllFileFilterUsed(true);
            if (JFileChooser.APPROVE_OPTION == jfc.showOpenDialog(Browser.getActiveBrowser()))
            {
                txt.setText(jfc.getSelectedFile().getAbsolutePath());
            }
        }
    }
}